@@ -1,10 +1,10 @@
 /* cdf/cdf_beta.c
  * 
- * Copyright (C) 2003 Brian Gough.
+ * Copyright (C) 2003, 2007 Brian Gough.
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at
+ * the Free Software Foundation; either version 3 of the License, or (at
  * your option) any later version.
  * 
  * This program is distributed in the hope that it will be useful, but
@@ -13,8 +13,8 @@
  * General Public License for more details.
  * 
  * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307, USA.
+ * along with this program; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  */
 
 #include <config.h>
@@ -48,7 +48,7 @@ gsl_cdf_beta_P (const double x, const double a, const double b)
 double
 gsl_cdf_beta_Q (const double x, const double a, const double b)
 {
-  double P;
+  double Q;
 
   if ( x >= 1.0)
     {
@@ -60,7 +60,7 @@ gsl_cdf_beta_Q (const double x, const double a, const double b)
       return 1.0;
     }
 
-  P = beta_inc_AXPY (-1.0, 1.0, a, b, x);
+  Q = beta_inc_AXPY (-1.0, 1.0, a, b, x);
 
-  return P;
+  return Q;
 }
