@@ -547,14 +547,15 @@ singular (const gsl_matrix * LU)
       if (u == 0) return 1;
     }
  
- return 0;
+  return 0;
 }
 
 static int
 apply_pivots(gsl_matrix * A, const gsl_vector_uint * ipiv)
 {
-  if (0)
+  if (A->size1 < ipiv->size)
     {
+      GSL_ERROR("matrix does not match pivot vector", GSL_EBADLEN);
     }
   else
     {
